Examples
========

`oedes` comes with examples demonstrating typical use. Each example shows usage of oedes and is used as a test suite to check for correctness. Many examples additionally partially or completely reproduce published papers. They therefore allow to experiment with published models.

The examples provided as files with extension ``.ipynb`` run in Jupyter Notebook. Before running the examples, `oedes` should be installed.

The examples are included in `oedes` source distribution, and can also be downloaded from oedes repository on github. Also, they can be browsed on `oedes` website.
